summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp')
-rw-r--r--tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp b/tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp
index 07543be..ab81bcb 100644
--- a/tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp
+++ b/tqtinterface/qt4/tools/designer/examples/credit/creditformbase.cpp
@@ -32,14 +32,14 @@ static TQPixmap uic_load_pixmap_CreditFormBase( const TQString &name )
return pix;
}
/*
* Constructs a CreditFormBase which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-CreditFormBase::CreditFormBase( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+CreditFormBase::CreditFormBase( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
setName( "CreditFormBase" );
@@ -32,14 +32,14 @@ static TQPixmap uic_load_pixmap_CreditFormBase( const TQString &name )
}
/*
- * Constructs a CreditFormBase which is a child of 'tqparent', with the
+ * Constructs a CreditFormBase which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*